package token

import (
	"strings"
)

// List is a slice of tokens.
type List []Token

// IndexKind returns the position of a token kind within a token list.
func (list List) IndexKind(kind Kind) int {
	for i, token := range list {
		if token.Kind == kind {
			return i
		}
	}

	return -1
}

// LastIndexKind returns the position of the last token kind within a token list.
func (list List) LastIndexKind(kind Kind) int {
	for i := len(list) - 1; i >= 0; i-- {
		if list[i].Kind == kind {
			return i
		}
	}

	return -1
}

// Text returns the concatenated token text.
func (list List) Text(source []byte) string {
	tmp := strings.Builder{}

	for _, t := range list {
		tmp.WriteString(t.Text(source))
	}

	return tmp.String()
}
